@@ -1,11 +1,13 @@
 /*
-  SPDX-FileCopyrightText: 2019-2020 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "markupdirector.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "markupdirector_p.h"
 
 #include "abstractmarkupbuilder.h"
@@ -291,10 +293,10 @@ QTextFrame::iterator MarkupDirector::processTable(QTextFrame::iterator it, QText
     QString sWidth;
 
     if (tableWidth.type() == QTextLength::PercentageLength) {
-        sWidth = QStringLiteral("%1%");
+        sWidth = u"%1%"_s;
         sWidth = sWidth.arg(tableWidth.rawValue());
     } else if (tableWidth.type() == QTextLength::FixedLength) {
-        sWidth = QStringLiteral("%1");
+        sWidth = u"%1"_s;
         sWidth = sWidth.arg(tableWidth.rawValue());
     }
 
@@ -337,9 +339,9 @@ QTextFrame::iterator MarkupDirector::processTable(QTextFrame::iterator it, QText
             QString sCellWidth;
 
             if (cellWidth.type() == QTextLength::PercentageLength) {
-                sCellWidth = QStringLiteral("%1%").arg(cellWidth.rawValue());
+                sCellWidth = u"%1%"_s.arg(cellWidth.rawValue());
             } else if (cellWidth.type() == QTextLength::FixedLength) {
-                sCellWidth = QStringLiteral("%1").arg(cellWidth.rawValue());
+                sCellWidth = u"%1"_s.arg(cellWidth.rawValue());
             }
 
             // TODO: Use THEAD instead
@@ -378,7 +380,8 @@ QPair<QTextFrame::iterator, QTextBlock> MarkupDirector::processList(QTextFrame::
     const auto style = list->format().style();
     m_builder->beginList(style);
     auto block = _block;
-    while (block.isValid() && block.textList()) {
+    auto curList = list;
+    while (block.isValid() && block.textList() && curList == list) {
         m_builder->beginListItem();
         processBlockContents(it, block);
         m_builder->endListItem();
@@ -387,7 +390,8 @@ QPair<QTextFrame::iterator, QTextBlock> MarkupDirector::processList(QTextFrame::
             ++it;
         }
         block = block.next();
-        if (block.isValid()) {
+        // Processing nested list
+        if (block.isValid() && block.textList() && block.textList()->format().indent() > list->format().indent()) {
             auto obj = block.document()->objectForFormat(block.blockFormat());
             auto group = qobject_cast<QTextBlockGroup *>(obj);
             if (group && group != list) {
@@ -396,6 +400,7 @@ QPair<QTextFrame::iterator, QTextBlock> MarkupDirector::processList(QTextFrame::
                 block = pair.second;
             }
         }
+        curList = qobject_cast<QTextList *>(block.document()->objectForFormat(block.blockFormat()));
     }
     m_builder->endList();
     return qMakePair(it, block);
@@ -473,7 +478,7 @@ QPair<QTextFrame::iterator, QTextBlock> MarkupDirector::processBlockGroup(const
 
 void MarkupDirector::processDocument(QTextDocument *doc)
 {
-    processFrame(QTextFrame::iterator(), doc->rootFrame());
+    std::ignore = processFrame(QTextFrame::iterator(), doc->rootFrame());
 }
 
 QTextBlock::iterator MarkupDirector::processCharTextObject(QTextBlock::iterator it, const QTextFragment &fragment, QTextObject *textObject)
@@ -515,7 +520,6 @@ void MarkupDirector::processClosingElements(const QTextBlock::iterator &it)
 
     auto elementsToClose = getElementsToClose(it);
 
-    int previousSize;
     auto remainingSize = elementsToClose.size();
     while (!elementsToClose.isEmpty()) {
         auto tag = d->m_openElements.last();
@@ -542,12 +546,12 @@ void MarkupDirector::processClosingElements(const QTextBlock::iterator &it)
             case SpanBackground:
                 m_builder->endBackground();
                 // Clear background otherwise if we select 2 lines with same color it will not applied. bug #442416
-                d->m_openBackground = {};
+                d->m_openBackground = QBrush();
                 break;
             case SpanForeground:
                 m_builder->endForeground();
                 // Clear foreground text color otherwise if we select 2 lines with same text color it will not applied. bug #442416
-                d->m_openForeground = {};
+                d->m_openForeground = QBrush();
                 break;
             case Anchor:
                 m_builder->endAnchor();
@@ -565,7 +569,7 @@ void MarkupDirector::processClosingElements(const QTextBlock::iterator &it)
             d->m_openElements.removeLast();
             elementsToClose.remove(tag);
         }
-        previousSize = remainingSize;
+        int previousSize = remainingSize;
         remainingSize = elementsToClose.size();
 
         if (previousSize == remainingSize) {
@@ -853,7 +857,7 @@ QList<int> MarkupDirector::sortOpeningOrder(QSet<int> openingOrder, QTextBlock::
     // sort, or the end is reached.
     while (!openingOrder.isEmpty()) {
         if (!it.atEnd()) {
-            it++;
+            ++it;
 
             if (!it.atEnd()) {
                 // Because I've iterated, this returns the elements that will
